@@ -636,6 +636,77 @@ RcppExport SEXP SPLUSSimulHaplo(SEXP sGenealogy, SEXP sProbands, SEXP sLenPro, S
 
 	return R_NilValue;
 }
+
+RcppExport SEXP SPLUSSimulHaplo_traceback(SEXP s_proID, SEXP s_ancestorID, SEXP s_indVec, SEXP s_fatherVec, SEXP s_motherVec, SEXP s_path_ANH, SEXP s_path_PH){
+
+	std::string path_ANH = Rcpp::as<std::string>(s_path_ANH);
+	std::string path_PH  = Rcpp::as<std::string>(s_path_PH);
+
+	int proID = *(INTEGER(s_proID));
+	int ancID = *(INTEGER(s_ancestorID));
+
+	Rcpp::IntegerVector w_indVec(s_indVec);
+	Rcpp::IntegerVector w_motherVec(s_motherVec);
+	Rcpp::IntegerVector w_fatherVec(s_fatherVec);
+
+	std::vector<int> indVec    = Rcpp::as<std::vector<int> >(w_indVec);
+	std::vector<int> motherVec = Rcpp::as<std::vector<int> >(w_motherVec);
+	std::vector<int> fatherVec = Rcpp::as<std::vector<int> >(w_fatherVec);
+
+	std::vector<int> resultvec1;   //simulno
+	resultvec1.reserve(100);  
+	std::vector<int> resultvec2;  // pathno
+	resultvec2.reserve(100);
+	std::vector<int> resultvec3;  //seg length
+	resultvec3.reserve(100);
+	//resultvec1 = std::vector<int> ... (make empty vectors for the results, then pass them into traceback function by reference, then copy them to R
+	//resultvec2 ...
+	simulhaplo_traceback(path_ANH, path_PH, proID, ancID, indVec, motherVec, fatherVec, resultvec1, resultvec2, resultvec3); //resultvec1, resultvec2....
+
+	//after traceback function is done, return a constructed dataframe
+	Rcpp::IntegerVector w_resultvec1 = Rcpp::wrap(resultvec1);
+	Rcpp::IntegerVector w_resultvec2 = Rcpp::wrap(resultvec2);
+	Rcpp::IntegerVector w_resultvec3 = Rcpp::wrap(resultvec3);
+
+	Rcpp::DataFrame results = Rcpp::DataFrame::create(
+		Rcpp::Named("simulNo") 		= w_resultvec1,
+		Rcpp::Named("seg_length")  	= w_resultvec2,
+		Rcpp::Named("path_n") 	    = w_resultvec3
+	);
+	
+	return results;
+}
+
+RcppExport SEXP SPLUSSimulHaplo_IBD_compare (SEXP s_pro_id1, SEXP s_pro_id2, SEXP s_BP_len, SEXP path_to_file){
+	int proID1 = *(INTEGER(s_pro_id1));
+	int proID2 = *(INTEGER(s_pro_id2));
+	int BP_len = *(INTEGER(s_BP_len)) ;
+
+	std::string path = Rcpp::as<std::string>(path_to_file);
+
+	std::vector<double> rvec3;
+	std::vector<int> rvec1, rvec2, rvec4;
+	rvec1.reserve(100);
+	rvec2.reserve(100);
+	rvec3.reserve(100);
+	rvec4.reserve(100);
+
+	simulhaplo_compare_IBD(proID1, proID2, BP_len, path, rvec1, rvec2, rvec3, rvec4);
+
+	Rcpp::IntegerVector w_rvec1 = Rcpp::wrap(rvec1);
+	Rcpp::IntegerVector w_rvec2 = Rcpp::wrap(rvec2);
+	Rcpp::NumericVector w_rvec3 = Rcpp::wrap(rvec3);
+	Rcpp::IntegerVector w_rvec4 = Rcpp::wrap(rvec4);
+
+	Rcpp::DataFrame results = Rcpp::DataFrame::create(
+		Rcpp::Named("simulNo") 		= w_rvec1,
+		Rcpp::Named("n_seg")  		= w_rvec2,
+		Rcpp::Named("pIBD") 	    = w_rvec3,
+		Rcpp::Named("mean_seg_len") = w_rvec4
+	);
+	
+	return results;
+}
 /*FONCTION D'INTERFACE POUR SPLUS*/
 
 /// Fonction d'interface Splus pour simul
